@@ -1,12 +1,11 @@
 
-
 class ListNode:
     def __init__(self, x):
         self.val = x
         self.next = None
 
 
-def make_list(arr: list):
+def make_list(arr):
     head_node = None
     p_node = None
     for a in arr:
@@ -20,7 +19,7 @@ def make_list(arr: list):
     return head_node
 
 
-def print_list(head: ListNode):
+def print_list(head):
     while head is not None:
         print(head.val, end=',')
         head = head.next
